@@ -1,7 +1,7 @@
-from .subreddit import Subreddit
-from .user import User
+from .subreddit import Subreddit, AsyncSubreddit
+from .user import User, AsyncUser
 from .exceptions import RequestError
 
-__version__ = "2.8.0"
+__version__ = "2.9.0"
 __author__ = "MakufonSkifto"
 __license__ = "GNU General Public License v3"
